# ![image](images/xFrame_logo_title.svg#only-light)![image](images/xFrame_logo_title_dark.svg#only-dark)
The main objective of __xFrame__ is to provide an easy and flexible framework that handles details such as

- Data storage / File access
- Settings management
- Multiprocessing
- GPU access

Allowing users to focus on the "scientific" part of their algorithm.  
*xFrame* has been created during our quest of writing a toolkit for fluctuation X-ray scattering.

The documentation for FXS can be found under [FXS](fxs/index.md).  
The documentation for the framework part is at [Framework](framework/index.md).

